//! # Me Responses
pub mod me;
pub use me::{Friend, MeData, Saved, SavedData};

pub mod inbox;
pub use inbox::{Inbox, InboxData};
